==> lib-react-0.0.9.tgz: package/src/hooks/useMap.tsx <==
import { useReducer } from 'react';

type Key = string | number | symbol;

interface State<K extends Key, V> {
  map: Map<K, V>;
}
interface Action<K extends Key, V> {
  type: 'set' | 'delete' | 'clear';
  key?: K;
  value?: V;
}

function createReducer<K extends Key, V>() {
  return function (state: State<K, V>, action: Action<K, V>) {
    switch (action.type) {
      case 'set': {
        state.map.set(action.key!, action.value!);
        break;
      }
      case 'delete': {
        state.map.delete(action.key!);
        break;
      }
      case 'clear': {
        state.map.clear();
        break;
      }
      default:
        break;
    }
    return {
      map: state.map,
    };
  };
}

export function useMap<K extends Key, V>(arr: [K, V][] = []) {
  const [state, dispatch] = useReducer(createReducer<K, V>(), {
    map: new Map<K, V>(arr),
  });

  return {
    get: (key: K) => state.map.get(key),
    set: (key: K, value: V) => dispatch({ type: 'set', key, value }),
    delete: (key: K) => dispatch({ type: 'delete', key }),
    clear: () => dispatch({ type: 'clear' }),
    forEach: (callback: (value: V, key: K, map: Map<K, V>) => void) =>
      state.map.forEach(callback),
    map: (callback: (value: [K, V], index: number, arr: [K, V][]) => void) =>
      [...state.map.entries()].map(callback),
    has: (key: K) => state.map.has(key),
    entries: () => state.map.entries(),
    values: () => state.map.values(),
    keys: () => state.map.keys(),
    size: state.map.size,
  };
}

==> lib-react-0.0.10.tgz: package/src/hooks/useMap.tsx <==
import { useReducer } from 'react';

type Key = string | number | symbol;

interface State<K extends Key, V> {
  map: Map<K, V>;
}
interface Action<K extends Key, V> {
  type: 'set' | 'delete' | 'clear';
  key?: K;
  value?: V;
}

function createReducer<K extends Key, V>() {
  return function (state: State<K, V>, action: Action<K, V>) {
    switch (action.type) {
      case 'set': {
        state.map.set(action.key!, action.value!);
        break;
      }
      case 'delete': {
        state.map.delete(action.key!);
        break;
      }
      case 'clear': {
        state.map.clear();
        break;
      }
      default:
        break;
    }
    return {
      map: state.map,
    };
  };
}

export function useMap<K extends Key, V>(arr: [K, V][] = []) {
  const [state, dispatch] = useReducer(createReducer<K, V>(), {
    map: new Map<K, V>(arr),
  });

  return {
    get: (key: K) => state.map.get(key),
    set: function (key: K, value: V) {
      dispatch({ type: 'set', key, value });
      return this as Map<K, V>;
    },
    delete: (key: K) => {
      if (!state.map.has(key)) return false;
      dispatch({ type: 'delete', key });
      return true;
    },
    clear: () => dispatch({ type: 'clear' }),
    forEach: (callback: (value: V, key: K, map: Map<K, V>) => void) =>
      state.map.forEach(callback),
    map: function <Result>(
      callback: (entry: [K, V], index: number, array: [K, V][]) => Result,
    ) {
      return [...state.map.entries()].map(callback);
    },
    has: (key: K) => state.map.has(key),
    entries: () => state.map.entries(),
    values: () => state.map.values(),
    keys: () => state.map.keys(),
    size: state.map.size,
    *[Symbol.iterator]() {
      const iterator1 = state.map[Symbol.iterator]();
      for (const item of iterator1) {
        yield item;
      }
    },
    [Symbol.toStringTag]: state.map[Symbol.toStringTag],
  };
}
